reth

package
v0.0.0-...-2668204 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 4, 2026 License: MIT Imports: 23 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewRethClient

func NewRethClient(logger log.Logger, options *config.InternalClientOptions, ports portmanager.PortManager) types.ExecutionClient

NewRethClient creates a new client for reth.

func NewRethClientWithBin

func NewRethClientWithBin(logger log.Logger, options *config.InternalClientOptions, ports portmanager.PortManager, binPath string) types.ExecutionClient

Types

type RethClient

type RethClient struct {
	// contains filtered or unexported fields
}

RethClient handles the lifecycle of a reth client.

func (*RethClient) AuthClient

func (r *RethClient) AuthClient() client.RPC

AuthClient returns the auth client used for CL communication.

func (*RethClient) Client

func (r *RethClient) Client() *ethclient.Client

Client returns the ethclient client.

func (*RethClient) ClientURL

func (r *RethClient) ClientURL() string

ClientURL returns the raw client URL for transaction generators.

func (*RethClient) FlashblocksClient

func (r *RethClient) FlashblocksClient() types.FlashblocksClient

FlashblocksClient returns nil as reth does not support flashblocks.

func (*RethClient) GetVersion

func (r *RethClient) GetVersion(ctx context.Context) (string, error)

GetVersion returns the version of the Reth client

func (*RethClient) MetricsCollector

func (r *RethClient) MetricsCollector() metrics.Collector

func (*RethClient) MetricsPort

func (r *RethClient) MetricsPort() int

func (*RethClient) Run

func (r *RethClient) Run(ctx context.Context, cfg *types.RuntimeConfig) error

Run runs the reth client with the given runtime config.

func (*RethClient) SetHead

func (r *RethClient) SetHead(ctx context.Context, blockNumber uint64) error

SetHead resets the blockchain to a specific block using debug.setHead

func (*RethClient) Stop

func (r *RethClient) Stop()

Stop stops the reth client.

func (*RethClient) SupportsFlashblocks

func (r *RethClient) SupportsFlashblocks() bool

SupportsFlashblocks returns true if the client supports receiving flashblock payloads. Reth supports flashblocks when configured with the appropriate flags.

Directories

Path Synopsis

Jump to