Documentation
¶
Index ¶
- func NewRethClient(logger log.Logger, options *config.InternalClientOptions, ...) types.ExecutionClient
- func NewRethClientWithBin(logger log.Logger, options *config.InternalClientOptions, ...) types.ExecutionClient
- type RethClient
- func (r *RethClient) AuthClient() client.RPC
- func (r *RethClient) Client() *ethclient.Client
- func (r *RethClient) ClientURL() string
- func (r *RethClient) FlashblocksClient() types.FlashblocksClient
- func (r *RethClient) GetVersion(ctx context.Context) (string, error)
- func (r *RethClient) MetricsCollector() metrics.Collector
- func (r *RethClient) MetricsPort() int
- func (r *RethClient) Run(ctx context.Context, cfg *types.RuntimeConfig) error
- func (r *RethClient) SetHead(ctx context.Context, blockNumber uint64) error
- func (r *RethClient) Stop()
- func (r *RethClient) SupportsFlashblocks() bool
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRethClient ¶
func NewRethClient(logger log.Logger, options *config.InternalClientOptions, ports portmanager.PortManager) types.ExecutionClient
NewRethClient creates a new client for reth.
func NewRethClientWithBin ¶
func NewRethClientWithBin(logger log.Logger, options *config.InternalClientOptions, ports portmanager.PortManager, binPath string) types.ExecutionClient
Types ¶
type RethClient ¶
type RethClient struct {
// contains filtered or unexported fields
}
RethClient handles the lifecycle of a reth client.
func (*RethClient) AuthClient ¶
func (r *RethClient) AuthClient() client.RPC
AuthClient returns the auth client used for CL communication.
func (*RethClient) Client ¶
func (r *RethClient) Client() *ethclient.Client
Client returns the ethclient client.
func (*RethClient) ClientURL ¶
func (r *RethClient) ClientURL() string
ClientURL returns the raw client URL for transaction generators.
func (*RethClient) FlashblocksClient ¶
func (r *RethClient) FlashblocksClient() types.FlashblocksClient
FlashblocksClient returns nil as reth does not support flashblocks.
func (*RethClient) GetVersion ¶
func (r *RethClient) GetVersion(ctx context.Context) (string, error)
GetVersion returns the version of the Reth client
func (*RethClient) MetricsCollector ¶
func (r *RethClient) MetricsCollector() metrics.Collector
func (*RethClient) MetricsPort ¶
func (r *RethClient) MetricsPort() int
func (*RethClient) Run ¶
func (r *RethClient) Run(ctx context.Context, cfg *types.RuntimeConfig) error
Run runs the reth client with the given runtime config.
func (*RethClient) SetHead ¶
func (r *RethClient) SetHead(ctx context.Context, blockNumber uint64) error
SetHead resets the blockchain to a specific block using debug.setHead
func (*RethClient) SupportsFlashblocks ¶
func (r *RethClient) SupportsFlashblocks() bool
SupportsFlashblocks returns true if the client supports receiving flashblock payloads. Reth supports flashblocks when configured with the appropriate flags.