Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LogWriter ¶
type LogWriter struct {
// contains filtered or unexported fields
}
func NewLogWriter ¶
NewLogWriter creates a new log writer that writes messages of a subprocess to the provided logger.
func NewLogWriterWithLevel ¶
type MultiWriterCloser ¶
func NewMultiWriterCloser ¶
func NewMultiWriterCloser(writerClosers ...io.WriteCloser) *MultiWriterCloser
func (*MultiWriterCloser) Close ¶
func (m *MultiWriterCloser) Close() error
Close closes all the underlying io.WriteCloser instances and returns the first error if any. If all close calls succeed, it returns nil.
Click to show internal directories.
Click to hide internal directories.